# Generated by roxygen2: do not edit by hand

S3method(plot,rmst_power)
S3method(plot,rmst_ss)
S3method(print,rmst_power)
S3method(print,rmst_simdata)
S3method(print,rmst_ss)
S3method(print,summary.rmst_power)
S3method(print,summary.rmst_simdata)
S3method(print,summary.rmst_ss)
S3method(summary,rmst_power)
S3method(summary,rmst_simdata)
S3method(summary,rmst_ss)
export(DC.power.analytical)
export(DC.ss.analytical)
export(GAM.power.boot)
export(GAM.ss.boot)
export(MS.power.analytical)
export(MS.power.boot)
export(MS.ss.analytical)
export(MS.ss.boot)
export(additive.power.analytical)
export(additive.ss.analytical)
export(covar_binary)
export(covar_categorical)
export(covar_continuous)
export(describe_generation)
export(gen_covariates)
export(generate_recipe_sets)
export(linear.power.analytical)
export(linear.power.boot)
export(linear.ss.analytical)
export(linear.ss.boot)
export(load_recipe_sets)
export(rebuild_manifest)
export(recipe_grid)
export(recipe_quick_aft)
export(recipe_quick_ph)
export(rmst.power)
export(rmst.sim)
export(rmst.ss)
export(run_app)
export(simulate_from_recipe)
export(validate_recipe)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future,sequential)
importFrom(future.apply,future_lapply)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,ylim)
importFrom(knitr,kable)
importFrom(magrittr,"%>%")
importFrom(mgcv,gam)
importFrom(mgcv,summary.gam)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,integrate)
importFrom(stats,lm)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,plogis)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,rexp)
importFrom(stats,rgamma)
importFrom(stats,rlnorm)
importFrom(stats,rnorm)
importFrom(stats,rt)
importFrom(stats,runif)
importFrom(stats,rweibull)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,stepfun)
importFrom(stats,uniroot)
importFrom(stats,vcov)
importFrom(stats,weighted.mean)
importFrom(survival,Surv)
importFrom(survival,basehaz)
importFrom(survival,coxph)
importFrom(survival,survfit)
importFrom(utils,head)
importFrom(utils,tail)
