% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generate_sets_datagen.R
\name{recipe_grid}
\alias{recipe_grid}
\title{Expand a recipe over a grid of values (list-only)}
\usage{
recipe_grid(base, vary)
}
\arguments{
\item{base}{A recipe list.}

\item{vary}{Named list of vectors; keys are dotted paths.}
}
\value{
A list of recipe lists.
}
\description{
Expand a recipe over a grid of values (list-only)
}
\examples{
r <- recipe_quick_aft(60, "aft_lognormal", baseline=list(mu=2.7, sigma=0.6),
       treat_effect=-0.2, covariates=list(list(name="x", type="continuous", dist="normal",
       params=list(mean=0, sd=1))))
recipe_grid(r, list(n=c(60,80), "event_time.effects.treatment"=c(-0.2,-0.4)))
}
