% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_app.R
\name{run_app}
\alias{run_app}
\title{Launch the RMSTpowerBoost Shiny Application}
\usage{
run_app(install_missing = TRUE, repos = getOption("repos"))
}
\arguments{
\item{install_missing}{Logical; if \code{TRUE}, prompt to install missing app
dependencies.}

\item{repos}{CRAN mirror(s) passed to \code{utils::install.packages()} when
installing missing app dependencies.}
}
\value{
Invisible return value from \code{shiny::runApp()}.
}
\description{
Launches the Shiny application bundled with the package.
App-specific dependencies are installed only when they are needed.
}
\examples{
\dontshow{if (interactive()) withAutoprint(\{ # examplesIf}
RMSTpowerBoost::run_app()
\dontshow{\}) # examplesIf}
}
