% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rmst-interface.R
\name{print.rmst_power}
\alias{print.rmst_power}
\alias{summary.rmst_power}
\alias{plot.rmst_power}
\title{Print an rmst_power result}
\usage{
\method{print}{rmst_power}(x, ...)

\method{summary}{rmst_power}(object, ...)

\method{plot}{rmst_power}(x, ...)
}
\arguments{
\item{x}{An object returned by \code{\link[=rmst.power]{rmst.power()}}.}

\item{...}{Additional arguments passed to or from other methods.}

\item{object}{An object returned by \code{\link[=rmst.power]{rmst.power()}}.}
}
\value{
The input object \code{x}, invisibly.

An object of class \code{"summary.rmst_power"}.

A \code{ggplot2} object, invisibly.
}
\description{
Prints the model metadata and power table returned by \code{\link[=rmst.power]{rmst.power()}}.

Returns a summary object for printing and further inspection.

Prints and returns the stored \code{ggplot2} object.
}
