% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-rmst-datasets.R
\docType{data}
\name{aft_lognormal_L12_n150}
\alias{aft_lognormal_L12_n150}
\title{Simulated dataset: AFT log-normal, L = 12, n = 150}
\format{
A data frame with 150 rows and 5 variables.
}
\description{
Columns:
\itemize{
\item time: observed time
\item status: event indicator (1 = event, 0 = censored)
\item arm: treatment arm (0 = control, 1 = treatment)
\item age: baseline age
\item gender: factor with two levels
}
}
\examples{
data(aft_lognormal_L12_n150)
table(aft_lognormal_L12_n150$arm)
}
\keyword{datasets}
